summaryrefslogtreecommitdiff
path: root/home/tilemap.asm
diff options
context:
space:
mode:
authorluckytyphlosion <10688458+luckytyphlosion@users.noreply.github.com>2018-01-23 17:39:09 -0500
committerluckytyphlosion <10688458+luckytyphlosion@users.noreply.github.com>2018-01-23 17:39:09 -0500
commita1951cefc09035e11077a433b28ec8c66b3b03db (patch)
tree4de98db5a6edb6d74192028d50893da2b764421f /home/tilemap.asm
parent79bd48f85c7dd1868264e290b12dad17a6e25b95 (diff)
Prefix wram labels with w, part 2.
Diffstat (limited to 'home/tilemap.asm')
-rw-r--r--home/tilemap.asm8
1 files changed, 4 insertions, 4 deletions
diff --git a/home/tilemap.asm b/home/tilemap.asm
index 9e15ed85b..00317e53b 100644
--- a/home/tilemap.asm
+++ b/home/tilemap.asm
@@ -117,7 +117,7 @@ PlaceVerticalMenuItems:: ; 1c89
inc hl
ld d, [hl]
call GetMenuTextStartCoord
- call Coord2Tile ; hl now contains the TileMap address where we will start printing text.
+ call Coord2Tile ; hl now contains the wTileMap address where we will start printing text.
inc de
ld a, [de] ; Number of items
inc de
@@ -207,7 +207,7 @@ MenuBoxCoord2Tile:: ; 1cfd
Coord2Tile:: ; 1d05
; Return the address of TileMap(c, b) in hl.
xor a
ld h, a
ld l, b
@@ -235,7 +235,7 @@ MenuBoxCoord2Attr:: ; 1d19
ld b, a
Coord2Attr:: ; 1d21
; Return the address of AttrMap(c, b) in hl.
xor a
ld h, a
ld l, b
@@ -251,7 +251,7 @@ Coord2Attr:: ; 1d21
xor a
ld b, a
add hl, bc
- bccoord 0, 0, AttrMap
+ bccoord 0, 0, wAttrMap
add hl, bc
ret
; 1d35
@@ -207,7 +207,7 @@ MenuBoxCoord2Tile:: ; 1cfd
Coord2Tile:: ; 1d05
-; Return the address of TileMap(c, b) in hl.
+; Return the address of wTileMap(c, b) in hl.
xor a
ld h, a
@@ -235,7 +235,7 @@ MenuBoxCoord2Attr:: ; 1d19
ld b, a
Coord2Attr:: ; 1d21
-; Return the address of AttrMap(c, b) in hl.
+; Return the address of wAttrMap(c, b) in hl.
xor a
ld h, a